@@ -2,12 +2,18 @@ from prsmsp.models.auth import APIKeyAuth, UnamePassAuth
 
 
 class AuthFactory:
+    """AuthFactory."""
 
     @staticmethod
-    def get(auth_type):
+    def get(auth_type: str):
+        """Static method to get the class of authentication.
+
+        :param auth_type:
+        :type auth_type: str
+        """
         auth_types = {
-            'api_key': APIKeyAuth,
-            'username_pass': UnamePassAuth,
+            "api_key": APIKeyAuth,
+            "username_pass": UnamePassAuth,
         }
 
         Auth = auth_types.get(auth_type, None)
